@@ -6,11 +6,14 @@ try:
 except ImportError:
     from yaml import Dumper
 
+import devassistant
+
 from devassistant import settings
-from devassistant import version
+from devassistant import yaml_checker
 from devassistant import yaml_loader
 from devassistant import yaml_snippet_loader
 
+
 class Cache(object):
     """Representation of DevAssistant cache file.
     Cache is stored in yaml file between devassistant invocations. Once it is loaded,
@@ -36,11 +39,11 @@ class Cache(object):
             'source': '/foo/bar/assistants/crt/c.yaml',
             # hierarchy of subassistants of this assistant
             'subhierarchy': {'d': {...}},
-     'mod': {...},
+     'twk': {...},
      'prep': {...},
-     'task': {...},
+     'extra': {...},
      # version of devassistant that cache has been created with
-     'version': VERSION}
+     'version': devassistant.__version__}
     """
 
     def __init__(self, cache_file=settings.CACHE_FILE):
@@ -55,20 +58,21 @@ class Cache(object):
         # snippets are shared across many assistants, so we remember their ctimes
         # here, because doing it again for each assistant would be very costly
         self.snip_ctimes = {}
-        # TODO: try/catch creating the cache file, on failure don't use it
         reset_cache = False
         if os.path.exists(self.cache_file):
             self.cache = yaml_loader.YamlLoader.load_yaml_by_path(cache_file) or {}
-            if self.cache.get('version', '0.0.0') != version.VERSION:
+            if self.cache.get('version', '0.0.0') != devassistant.__version__:
                 reset_cache = True
         else:
             if not os.path.exists(os.path.dirname(cache_file)):
                 os.makedirs(os.path.dirname(cache_file))
             reset_cache = True
 
+        # if writing the file raises, YamlAssistantLoader catches the exception
+        #  and doesn't use cache at all
         if reset_cache:
             f = open(cache_file, 'w')
-            self.cache = {'version': version.VERSION}
+            self.cache = {'version': devassistant.__version__}
             f.close()
 
     def refresh_role(self, role, file_hierarchy):
@@ -79,7 +83,7 @@ class Cache(object):
             file_hierarchy: hierarchy as returned by devassistant.yaml_assistant_loader.\
                             YamlAssistantLoader.get_assistants_file_hierarchy
         """
-        if not role in self.cache:
+        if role not in self.cache:
             self.cache[role] = {}
         was_change = self._refresh_hierarchy_recursive(self.cache[role], file_hierarchy)
         if was_change:
@@ -128,11 +132,12 @@ class Cache(object):
             if needs_refresh:
                 self._ass_refresh_attrs(cached_hierarchy[ass], file_hierarchy[ass])
                 was_change = True
-            was_change |= self._refresh_hierarchy_recursive(cached_hierarchy[ass]['subhierarchy'], file_hierarchy[ass]['subhierarchy'])
+            was_change |= self._refresh_hierarchy_recursive(
+                cached_hierarchy[ass]['subhierarchy'],
+                file_hierarchy[ass]['subhierarchy'])
 
         return was_change
 
-
     def _ass_needs_refresh(self, cached_ass, file_ass):
         """Checks if assistant needs refresh.
 
@@ -171,8 +176,9 @@ class Cache(object):
                       (for format see what refresh_role accepts)
         """
         # we need to process assistant in custom way to see unexpanded args, etc.
-        loaded_ass = yaml_loader.YamlLoader.load_yaml_by_path(file_ass['source'])
-        _, attrs = loaded_ass.popitem()
+        loaded_ass = yaml_loader.YamlLoader.load_yaml_by_path(file_ass['source'], log_debug=True)
+        attrs = loaded_ass
+        yaml_checker.check(file_ass['source'], attrs)
         cached_ass['source'] = file_ass['source']
         cached_ass['ctime'] = os.path.getctime(file_ass['source'])
         cached_ass['attrs'] = {}
