@@ -35,7 +35,10 @@ class Command(object):
         return cls.command_runners
 
     def __init__(self, comm_type, comm, kwargs={}):
-        self.comm_type = comm_type
+        if '.' in comm_type:
+            self.prefix, self.comm_type = comm_type.rsplit('.', 1)
+        else:
+            self.prefix, self.comm_type = '', comm_type
         self.comm = comm
         self.had_exec_flag = False
         if comm_type.endswith('~'):
@@ -48,12 +51,18 @@ class Command(object):
         self.kwargs = kwargs
 
     def run(self):
-        for cr in type(self).load_command_runners().command_runners:
-            if cr.matches(self):
-                return cr.run(self)
+        for crs_prefix, crs in type(self).load_command_runners().command_runners.items():
+            if self.prefix == crs_prefix:
+                # traverse in reversed order, so that dynamically loaded user command runners
+                #  can outrun (=> override) the builtin ones
+                for cr in reversed(crs):
+                    if cr.matches(self):
+                        return cr.run(self)
 
-        raise exceptions.CommandException('No runner for command "{ct}: {c}".'.\
-            format(ct=self.comm_type, c=self.input_res))
+        prefix_with_colon = self.prefix + '.' if self.prefix else self.prefix
+        raise exceptions.CommandException(
+            'No runner for command "{p}{ct}: {c}".'.
+            format(p=prefix_with_colon, ct=self.comm_type, c=self.input_res))
 
     @property
     def input_log_res(self):
@@ -138,7 +147,7 @@ def run_section(section, kwargs=None, runner=None):
 
 def eval_exec_section(section, kwargs, runner=None):
     skip_else = False
-    retval = [False, '']
+    retval = (False, '')
 
     if isinstance(section, six.string_types):
         return evaluate_expression(section, kwargs)
@@ -183,8 +192,8 @@ def eval_exec_section(section, kwargs, runner=None):
                 retval = Command(comm_type, comm, kwargs=kwargs).run()
 
             if not isinstance(retval, (list, tuple)) or len(retval) != 2:
-                raise exceptions.RunException('Bad return value of last command ({ct}: {c}): {r}'.\
-                        format(ct=comm_type, c=comm, r=retval))
+                raise exceptions.RunException('Bad return value of last command ({ct}: {c}): {r}'.
+                                              format(ct=comm_type, c=comm, r=retval))
             assign_last_result(kwargs, *retval)
 
     return retval
@@ -216,21 +225,19 @@ def eval_literal_section(section, kwargs, runner=None):
     elif isinstance(section, list):
         retlist = []
         for item in section:
-            # TODO: check for stop flag
             retlist.append(eval_literal_section(item, kwargs)[1])
         retval = (bool(retlist), retlist)
     elif isinstance(section, dict):
         retdict = {}
         for k, v in section.items():
             k = format_str(k, kwargs)
-            # TODO: check for stop flag
             if k.endswith('~'):
                 retdict[k[:-1]] = eval_exec_section(v, kwargs, runner)[1]
             else:
                 retdict[k] = eval_literal_section(v, kwargs, runner)[1]
         retval = (bool(retdict), retdict)
-    elif isinstance(section, bool):
-        retval = (section, section)
+    else:  # bool, int, float
+        retval = (bool(section), section)
 
     return retval
 
@@ -281,8 +288,8 @@ def get_for_control_var_and_eval_expr(comm_type, kwargs):
     iterval = []
     if len(control_vars) == 2:
         if not isinstance(eval_expression, dict):
-            raise exceptions.YamlSyntaxError('Can\'t expand {t} to two control variables.'.\
-                    format(t=type(eval_expression)))
+            raise exceptions.YamlSyntaxError('Can\'t expand {t} to two control variables.'.
+                                             format(t=type(eval_expression)))
         else:
             iterval = list(eval_expression.items())
     elif isinstance(eval_expression, six.string_types):
@@ -290,6 +297,9 @@ def get_for_control_var_and_eval_expr(comm_type, kwargs):
             iterval = eval_expression.split()
         else:
             iterval = eval_expression
+    else:
+        iterval = eval_expression
+
     return control_vars, iterval
 
 
@@ -371,7 +381,7 @@ def get_var_name(dollar_variable):
     return matched.group(1)
 
 
-### Expression evaluation
+# Expression evaluation
 class Interpreter(object):
     """
     Interpreter for DevAssistants DSL implemented using Pratt's parser.
@@ -449,7 +459,7 @@ class Interpreter(object):
     def tokenize(self, program):
         self.in_shell = False
         lexer = shlex.shlex(program)
-        lexer.wordchars += "$-/\\.:`={}"
+        lexer.wordchars += "$-/\\.:`!={}~&|"
 
         for tok in lexer:
             if tok in ["and", "or", "not", "defined", "(", ")", "in", "$", "as_root"]:
@@ -507,7 +517,7 @@ class Interpreter(object):
 def evaluate_expression(expression, names):
     interpr = Interpreter(names)
 
-    ## Language definition
+    # Language definition
     # First, add all the symbols, along with their binding power
     interpr.symbol("and", 10)
     interpr.symbol("or", 10)
@@ -540,7 +550,10 @@ def evaluate_expression(expression, names):
         # If there is a known variable in the literal, substitute it for its
         # value
         for v in reversed(sorted(interpr.names.keys())):
-            self.value = self.value.replace("$" + v, six.text_type(interpr.names[v]))
+            val = interpr.names[v]
+            if not six.PY3 and isinstance(val, str):
+                val = val.decode('utf-8')
+            self.value = self.value.replace("$" + v, six.text_type(val))
         # if self.value is in double/single quotes, strip them (but only the outer quotes)
         ret = self.value
         if ret.startswith('"'):
@@ -616,8 +629,9 @@ def evaluate_expression(expression, names):
 
         cmd = " ".join(cmd)
 
-        # Substitute the variables
-        formatted_cmd = format_str(cmd, interpr.names)
+        if (cmd.startswith('"') and cmd.endswith('"')) or \
+                (cmd.startswith("'") and cmd.endswith("'")):
+            cmd = cmd[1:-1]
 
         success = True
         exec_mode = 'cl_r' if interpr.as_root else 'cl'
@@ -689,13 +703,9 @@ def format_str(s, kwargs):
     new_comm = []
     parts_list = _command_splitter.findall(comm)
 
-    # replace parts that match something from _files (can be either name
-    # if "&" didn't expand in yaml; or the dict if "&" did expand)
+    # replace parts that match something from _files
     for c in parts_list:
-        if isinstance(c, dict):
-            # TODO: raise a proper error if c['source'] is not present
-            new_comm.append(os.path.join(files_dir, c['source']))
-        elif c.startswith('*'):
+        if c.startswith('*'):
             c_file = c[1:].strip('{}')
             if c_file in files:
                 new_comm.append(os.path.join(files_dir, files[c_file]['source']))
