@@ -1,8 +1,11 @@
+from io import StringIO
+import logging
 import os
-import pytest
 import sys
 import tempfile
-from io import StringIO
+
+from flexmock import flexmock
+import pytest
 
 from devassistant.command_helpers import ClHelper, CliDialogHelper
 from devassistant.exceptions import ClException
@@ -11,7 +14,7 @@ from test.logger import TestLoggingHandler
 
 class TestClHelper(object):
     def setup_method(self, method):
-        self.tlh = TestLoggingHandler()
+        self.tlh = TestLoggingHandler.create_fresh_handler()
 
     def test_command_processors(self):
         def foo(cmd_str):
@@ -61,6 +64,26 @@ class TestClHelper(object):
         finally:
             os.chdir(cwd)
 
+    @pytest.mark.parametrize(('correct', 'wrong', 'system_exe'), [
+        ('bash', '/usr/libexec/da_auth', False),
+        ('/usr/libexec/da_auth', 'bash', True),
+    ])
+    # TODO: remove
+    # Skipping tests in Python 3.4 due to https://github.com/has207/flexmock/pull/100
+    @pytest.mark.skipif(sys.version_info[:2] == (3, 4), reason='Skipped due to flexmock bug in Python 3.4')
+    def test_format_as_another_user_picks_the_right_exe(self, correct, wrong, system_exe):
+        flexmock(os.path).should_receive('isfile').with_args('/usr/libexec/da_auth').and_return(system_exe)
+        flexmock(os).should_receive('access').with_args('/usr/libexec/da_auth', 1).and_return(system_exe)
+
+        assert correct in ClHelper.format_for_another_user('foo', 'root')
+        assert wrong not in ClHelper.format_for_another_user('foo', 'root')
+
+    def test_log_secret(self):
+        ClHelper.run_command('id', log_level=logging.INFO, log_secret=True)
+        assert len(self.tlh.msgs)
+        assert ('INFO', 'LOGGING PREVENTED FOR SECURITY REASONS') in self.tlh.msgs
+        assert ('DEBUG', '0') in self.tlh.msgs
+
 
 class TestCliDialogHelper(object):
     def setup_method(self, method):
@@ -114,3 +137,26 @@ class TestCliDialogHelper(object):
     def test_ask_for_package_list_confirm_eof_error(self):
         CliDialogHelper.inp = self.eofraiser
         assert CliDialogHelper.ask_for_package_list_confirm('asd', ['sdf']) is None
+
+    @pytest.mark.parametrize(('inp', 'prompt', 'message', 'expected'), [
+        (u'foo', u'bar', u'baz', u'foo'),
+        (u'', u'baz', None, u''),
+        ])
+    def test_ask_for_user_input(self, inp, prompt, message, expected, capsys):
+        sys.stdin = StringIO(inp)
+        options = {}
+        if message:
+            options['message'] = message
+        result = CliDialogHelper.ask_for_input_with_prompt(prompt, **options)
+        stdout, stderr = capsys.readouterr()
+        assert prompt in stdout
+        if message:
+            assert message in stdout
+        assert result == expected
+
+    def test_env(self):
+        out = ClHelper.run_command('echo $DEVASSISTANTTESTFOO', env={'DEVASSISTANTTESTFOO': 'foo'})
+        assert out == 'foo'
+        # if the variable is not specified, check that there's nothing printed
+        out = ClHelper.run_command('echo $DEVASSISTANTTESTFOO')
+        assert out == ''
